(function(){
	/**
	 * MongoClient class.
	 */
	MongoClient = function(){this._init();};
	MongoClient._AUTH_FILE_ = "/usr/local/jetapps/etc/.mongod.auth";
	MongoClient.prototype = {
		_user: null,
		_pass: null,
		_db:   null,
		/** 
		 * Initialize the class. Set Admin user and password from the configuration file. 
		 */
		_init: function(){
			var file = cat(MongoClient._AUTH_FILE_);
			var lines = file.split(/\s*\r?\n\s*/);
			for(var i=0; i<lines.length; i++){
				var line = lines[i];
				if(!line) continue;
				var c = line.split(/\s*=\s*/, 2);
				if(c.length < 2) continue;
				if(c[0] == "PASS") this._pass = c[1];
				else if(c[0] == "USER") this._user = c[1];
			}
			if(!this._user || !this._pass) throw new Error("No User or Password");
			this.setDB(db.getName());
		},
		
		/**
		 * Get the root user.
		 */
		getRootUser: function(){
			return this._user;
		},
		
		/**
		 * Get the root password.
		 */
		getRootPass: function(){ 
			return this._pass; 
		},
		
		/**
		 * Authenticate using the current username and password.
		 */
		authenticate: function(){
			var _dbName = db.getName();
			this.setDB("admin");
			if(!this._db.auth(this.getRootUser(), this.getRootPass())){
				throw new Error("No User or Password");
			}
			this.setDB(_dbName);
		},
		
		/**
		 * Set dbname as the current database.
		 * @param string dbname the database name to set to
		 */
		setDB: function(dbname){
			this._db = db.getSiblingDB(dbname);
		},
		
		/**
		 * Add user to the current database
		 * @param string user - the user name
		 * @param string passwd - the password to set for the user
		 * @param opbject[] roles - the roles to set for the user.
		 * @throws Error if creation wasn't successful.
		 */
		addUser: function(user, passwd, roles){
			this.removeUser(user);
			try {
				this._db.createUser({ 
					user: user, 
					pwd: passwd, 
					roles: roles
				});
			}catch(e){
				throw new Error("Failed to create '"+user+"' user");
			}	
			
		},
		
		/**
		 * Remove the given user from the current database.
		 * @param string user - the name of the user to remove.
		 * 
		 */
		removeUser: function(user){
			this._db.dropUser(user);
		},
		
		/**
		 * Remove the current database.
		 */
		removeDB: function(){
			this._db.dropDatabase();
		}
	};
})();

